@@ -7,6 +7,7 @@ import (
 	"io/ioutil"
 	"net/http"
 	"os"
+	"time"
 
 	"github.com/gophercloud/gophercloud"
 	"github.com/gophercloud/gophercloud/openstack"
@@ -75,6 +76,8 @@ func (o *openStackClient) GetShareTypes() ([]sharetypes.ShareType, error) {
 		provider.HTTPClient = client
 	}
 
+	provider.HTTPClient.Timeout = 120 * time.Second
+
 	err = openstack.Authenticate(provider, *opts)
 	if err != nil {
 		return nil, fmt.Errorf("cannot authenticate with given credentials: %w", err)
